@@ -4,7 +4,7 @@ use 5.008_005;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.03'; # Set automatically by milla
+our $VERSION = '0.04'; # Set automatically by milla
 
 my $based = {
 	'default.base' => 'Rest::HtmlVis::Base',
@@ -22,14 +22,14 @@ sub new {
 	$self->{baseurl} = "/static";
 	$self->{baseurl} = $params->{'default.baseurl'} if exists $params->{'default.baseurl'};
 
-	### Set params
-	foreach my $key (keys %$params) {
-		$based->{$key} = $params->{$key};
+	### Add htmlvis
+	foreach my $key (sort keys %$params){
+		$self->loadVisObject($key, $params->{$key});
 	}
 
-	### Add htmlvis
-	foreach my $key (sort keys %{$based}){
-		$self->loadVisObject($key, $based->{$key});
+	### Set params
+	foreach my $key (sort keys %$based) {
+		$self->loadVisObject($key, $based->{$key}) unless exists $params->{$key};
 	}
 
 	return $self;
